@@ -18,9 +18,14 @@ from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_codeguruprofiler.paginator import ListProfileTimesPaginator
-
-from .literals import AggregationPeriod, ComputePlatform, FeedbackType, MetadataField, OrderBy
+from .literals import (
+    AggregationPeriodType,
+    ComputePlatformType,
+    FeedbackTypeType,
+    MetadataFieldType,
+    OrderByType,
+)
+from .paginator import ListProfileTimesPaginator
 from .type_defs import (
     AddNotificationChannelsResponseTypeDef,
     AgentOrchestrationConfigTypeDef,
@@ -74,7 +79,7 @@ class Exceptions:
 
 class CodeGuruProfilerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -85,8 +90,8 @@ class CodeGuruProfilerClient:
         self, channels: List["ChannelTypeDef"], profilingGroupName: str
     ) -> AddNotificationChannelsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
-        [Show boto3-stubs documentation](./client.md#add-notification-channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
+        [Show boto3-stubs documentation](./client.md#add_notification_channels)
         """
 
     def batch_get_frame_metric_data(
@@ -96,28 +101,28 @@ class CodeGuruProfilerClient:
         frameMetrics: List["FrameMetricTypeDef"] = None,
         period: str = None,
         startTime: datetime = None,
-        targetResolution: AggregationPeriod = None,
+        targetResolution: AggregationPeriodType = None,
     ) -> BatchGetFrameMetricDataResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
-        [Show boto3-stubs documentation](./client.md#batch-get-frame-metric-data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
+        [Show boto3-stubs documentation](./client.md#batch_get_frame_metric_data)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def configure_agent(
         self,
         profilingGroupName: str,
         fleetInstanceId: str = None,
-        metadata: Dict[MetadataField, str] = None,
+        metadata: Dict[MetadataFieldType, str] = None,
     ) -> ConfigureAgentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
-        [Show boto3-stubs documentation](./client.md#configure-agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        [Show boto3-stubs documentation](./client.md#configure_agent)
         """
 
     def create_profiling_group(
@@ -125,26 +130,26 @@ class CodeGuruProfilerClient:
         clientToken: str,
         profilingGroupName: str,
         agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = None,
-        computePlatform: ComputePlatform = None,
+        computePlatform: ComputePlatformType = None,
         tags: Dict[str, str] = None,
     ) -> CreateProfilingGroupResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
-        [Show boto3-stubs documentation](./client.md#create-profiling-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        [Show boto3-stubs documentation](./client.md#create_profiling_group)
         """
 
     def delete_profiling_group(self, profilingGroupName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
-        [Show boto3-stubs documentation](./client.md#delete-profiling-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        [Show boto3-stubs documentation](./client.md#delete_profiling_group)
         """
 
     def describe_profiling_group(
         self, profilingGroupName: str
     ) -> DescribeProfilingGroupResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
-        [Show boto3-stubs documentation](./client.md#describe-profiling-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        [Show boto3-stubs documentation](./client.md#describe_profiling_group)
         """
 
     def generate_presigned_url(
@@ -155,30 +160,30 @@ class CodeGuruProfilerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_findings_report_account_summary(
         self, dailyReportsOnly: bool = None, maxResults: int = None, nextToken: str = None
     ) -> GetFindingsReportAccountSummaryResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
-        [Show boto3-stubs documentation](./client.md#get-findings-report-account-summary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
+        [Show boto3-stubs documentation](./client.md#get_findings_report_account_summary)
         """
 
     def get_notification_configuration(
         self, profilingGroupName: str
     ) -> GetNotificationConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
-        [Show boto3-stubs documentation](./client.md#get-notification-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
+        [Show boto3-stubs documentation](./client.md#get_notification_configuration)
         """
 
     def get_policy(self, profilingGroupName: str) -> GetPolicyResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
-        [Show boto3-stubs documentation](./client.md#get-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
+        [Show boto3-stubs documentation](./client.md#get_policy)
         """
 
     def get_profile(
@@ -191,16 +196,16 @@ class CodeGuruProfilerClient:
         startTime: datetime = None,
     ) -> GetProfileResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
-        [Show boto3-stubs documentation](./client.md#get-profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        [Show boto3-stubs documentation](./client.md#get_profile)
         """
 
     def get_recommendations(
         self, endTime: datetime, profilingGroupName: str, startTime: datetime, locale: str = None
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
-        [Show boto3-stubs documentation](./client.md#get-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_recommendations)
         """
 
     def list_findings_reports(
@@ -213,37 +218,37 @@ class CodeGuruProfilerClient:
         nextToken: str = None,
     ) -> ListFindingsReportsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
-        [Show boto3-stubs documentation](./client.md#list-findings-reports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
+        [Show boto3-stubs documentation](./client.md#list_findings_reports)
         """
 
     def list_profile_times(
         self,
         endTime: datetime,
-        period: AggregationPeriod,
+        period: AggregationPeriodType,
         profilingGroupName: str,
         startTime: datetime,
         maxResults: int = None,
         nextToken: str = None,
-        orderBy: OrderBy = None,
+        orderBy: OrderByType = None,
     ) -> ListProfileTimesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
-        [Show boto3-stubs documentation](./client.md#list-profile-times)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        [Show boto3-stubs documentation](./client.md#list_profile_times)
         """
 
     def list_profiling_groups(
         self, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
     ) -> ListProfilingGroupsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
-        [Show boto3-stubs documentation](./client.md#list-profiling-groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        [Show boto3-stubs documentation](./client.md#list_profiling_groups)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def post_agent_profile(
@@ -254,8 +259,8 @@ class CodeGuruProfilerClient:
         profileToken: str = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
-        [Show boto3-stubs documentation](./client.md#post-agent-profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        [Show boto3-stubs documentation](./client.md#post_agent_profile)
         """
 
     def put_permission(
@@ -266,61 +271,61 @@ class CodeGuruProfilerClient:
         revisionId: str = None,
     ) -> PutPermissionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
-        [Show boto3-stubs documentation](./client.md#put-permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
+        [Show boto3-stubs documentation](./client.md#put_permission)
         """
 
     def remove_notification_channel(
         self, channelId: str, profilingGroupName: str
     ) -> RemoveNotificationChannelResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
-        [Show boto3-stubs documentation](./client.md#remove-notification-channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
+        [Show boto3-stubs documentation](./client.md#remove_notification_channel)
         """
 
     def remove_permission(
         self, actionGroup: Literal["agentPermissions"], profilingGroupName: str, revisionId: str
     ) -> RemovePermissionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
-        [Show boto3-stubs documentation](./client.md#remove-permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
+        [Show boto3-stubs documentation](./client.md#remove_permission)
         """
 
     def submit_feedback(
         self,
         anomalyInstanceId: str,
         profilingGroupName: str,
-        type: FeedbackType,
+        type: FeedbackTypeType,
         comment: str = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
-        [Show boto3-stubs documentation](./client.md#submit-feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
+        [Show boto3-stubs documentation](./client.md#submit_feedback)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_profiling_group(
         self, agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef", profilingGroupName: str
     ) -> UpdateProfilingGroupResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
-        [Show boto3-stubs documentation](./client.md#update-profiling-group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        [Show boto3-stubs documentation](./client.md#update_profiling_group)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_profile_times"]
     ) -> ListProfileTimesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](./paginators.md#listprofiletimespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](./paginators.md#listprofiletimespaginator)
         """
