@@ -23,7 +23,7 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import AggregationPeriod, OrderBy
+from .literals import AggregationPeriodType, OrderByType
 from .type_defs import ListProfileTimesResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListProfileTimesPaginator",)
@@ -31,19 +31,19 @@ __all__ = ("ListProfileTimesPaginator",)
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](./paginators.md#listprofiletimespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)[Show boto3-stubs documentation](./paginators.md#listprofiletimespaginator)
     """
 
     def paginate(
         self,
         endTime: datetime,
-        period: AggregationPeriod,
+        period: AggregationPeriodType,
         profilingGroupName: str,
         startTime: datetime,
-        orderBy: OrderBy = None,
+        orderBy: OrderByType = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProfileTimesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         [Show boto3-stubs documentation](./paginators.md#listprofiletimespaginator)
         """
